@@ -1,6 +1,7 @@
 from typing import cast
 
 import langgraph.version
+import structlog
 from starlette.responses import JSONResponse, PlainTextResponse
 
 from langgraph_api import __version__, config, metadata
@@ -13,6 +14,8 @@ from langgraph_runtime.ops import Runs
 
 METRICS_FORMATS = {"prometheus", "json"}
 
+logger = structlog.stdlib.get_logger(__name__)
+
 
 async def meta_info(request: ApiRequest):
     plus = plus_features_enabled()
@@ -71,35 +74,44 @@ async def meta_metrics(request: ApiRequest):
                 resp["workers"] = worker_metrics
             return JSONResponse(resp)
     elif metrics_format == "prometheus":
-        async with connect() as conn:
-            queue_stats = await Runs.stats(conn)
+        metrics = []
+        try:
+            async with connect() as conn:
+                queue_stats = await Runs.stats(conn)
 
-            metrics = [
-                "# HELP lg_api_num_pending_runs The number of runs currently pending.",
-                "# TYPE lg_api_num_pending_runs gauge",
-                f'lg_api_num_pending_runs{{project_id="{metadata.PROJECT_ID}", revision_id="{metadata.HOST_REVISION_ID}"}} {queue_stats["n_pending"]}',
-                "# HELP lg_api_num_running_runs The number of runs currently running.",
-                "# TYPE lg_api_num_running_runs gauge",
-                f'lg_api_num_running_runs{{project_id="{metadata.PROJECT_ID}", revision_id="{metadata.HOST_REVISION_ID}"}} {queue_stats["n_running"]}',
-            ]
-
-            if config.N_JOBS_PER_WORKER > 0:
                 metrics.extend(
                     [
-                        "# HELP lg_api_workers_max The maximum number of workers available.",
-                        "# TYPE lg_api_workers_max gauge",
-                        f'lg_api_workers_max{{project_id="{metadata.PROJECT_ID}", revision_id="{metadata.HOST_REVISION_ID}"}} {workers_max}',
-                        "# HELP lg_api_workers_active The number of currently active workers.",
-                        "# TYPE lg_api_workers_active gauge",
-                        f'lg_api_workers_active{{project_id="{metadata.PROJECT_ID}", revision_id="{metadata.HOST_REVISION_ID}"}} {workers_active}',
-                        "# HELP lg_api_workers_available The number of available (idle) workers.",
-                        "# TYPE lg_api_workers_available gauge",
-                        f'lg_api_workers_available{{project_id="{metadata.PROJECT_ID}", revision_id="{metadata.HOST_REVISION_ID}"}} {workers_available}',
+                        "# HELP lg_api_num_pending_runs The number of runs currently pending.",
+                        "# TYPE lg_api_num_pending_runs gauge",
+                        f'lg_api_num_pending_runs{{project_id="{metadata.PROJECT_ID}", revision_id="{metadata.HOST_REVISION_ID}"}} {queue_stats["n_pending"]}',
+                        "# HELP lg_api_num_running_runs The number of runs currently running.",
+                        "# TYPE lg_api_num_running_runs gauge",
+                        f'lg_api_num_running_runs{{project_id="{metadata.PROJECT_ID}", revision_id="{metadata.HOST_REVISION_ID}"}} {queue_stats["n_running"]}',
                     ]
                 )
+        except Exception as e:
+            # if we get a db connection error/timeout, just skip queue stats
+            await logger.awarning(
+                "Ignoring error while getting run stats for /metrics", exc_info=e
+            )
 
-            metrics.extend(http_metrics)
-            metrics.extend(pg_redis_stats)
+        if config.N_JOBS_PER_WORKER > 0:
+            metrics.extend(
+                [
+                    "# HELP lg_api_workers_max The maximum number of workers available.",
+                    "# TYPE lg_api_workers_max gauge",
+                    f'lg_api_workers_max{{project_id="{metadata.PROJECT_ID}", revision_id="{metadata.HOST_REVISION_ID}"}} {workers_max}',
+                    "# HELP lg_api_workers_active The number of currently active workers.",
+                    "# TYPE lg_api_workers_active gauge",
+                    f'lg_api_workers_active{{project_id="{metadata.PROJECT_ID}", revision_id="{metadata.HOST_REVISION_ID}"}} {workers_active}',
+                    "# HELP lg_api_workers_available The number of available (idle) workers.",
+                    "# TYPE lg_api_workers_available gauge",
+                    f'lg_api_workers_available{{project_id="{metadata.PROJECT_ID}", revision_id="{metadata.HOST_REVISION_ID}"}} {workers_available}',
+                ]
+            )
+
+        metrics.extend(http_metrics)
+        metrics.extend(pg_redis_stats)
 
         metrics_response = "\n".join(metrics)
         return PlainTextResponse(metrics_response)
