@@ -31,6 +31,10 @@ class Fragment(NamedTuple):
     buf: bytes
 
 
+def fragment_loads(data: bytes) -> Fragment:
+    return Fragment(data)
+
+
 def decimal_encoder(dec_value: Decimal) -> int | float:
     """
     Encodes a Decimal as int of there's no exponent, otherwise float
@@ -145,9 +149,10 @@ def json_loads(content: bytes | Fragment | dict) -> Any:
         content = content.buf
     if isinstance(content, dict):
         return content
-    return orjson.loads(cast(bytes, content))
+    return orjson.loads(content)
 
 
+# Do not use. orjson holds the GIL the entire time it's running anyway.
 async def ajson_loads(content: bytes | Fragment) -> Any:
     return await asyncio.to_thread(json_loads, content)
 
